model TdMoteurCcChaineTransmissionEleve
  class DCMotor "DC Motor"
    //Icon
    extends Modelica.Icons.MotorIcon;
    extends Servomechanisms.Utilities.IconName;
    //Parameters
    parameter SIunits.Resistance R = 0.128 "Armature Resistance";
    parameter SIunits.Inductance L = 0.000062 "Armature Inductance";
    parameter SIunits.ElectricalTorqueConstant kt = 0.0305 "Torque Constant";
    parameter SIunits.Inertia J = 0.000121 "Rotor Inertia";
    //parameter SIunits.RotationalDampingConstant b = 0 "Damping Factor";
    parameter SIunits.Torque t_m = 0.001 "Max. Friction torque";
    //Components
    Modelica.Electrical.Analog.Basic.Resistor resistor(R = R) annotation(
      Placement(visible = true, transformation(origin = {-75, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Basic.Inductor inductor(L = L) annotation(
      Placement(visible = true, transformation(origin = {-25, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Basic.EMF emf(k = kt) annotation(
      Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Components.Inertia inertia(J = J) annotation(
      Placement(visible = true, transformation(origin = {75, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Components.Damper damper(d = 0.00001) annotation(
      Placement(visible = true, transformation(origin = {60, -25}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
    Modelica.Mechanics.Rotational.Components.Fixed fixed annotation(
      Placement(visible = true, transformation(origin = {60, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Components.BearingFriction bearingfriction(peak = 1, tau_pos = [0, t_m]) annotation(
      Placement(visible = true, transformation(origin = {40, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    //Sensors
    //Interfaces
    Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
      Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Interfaces.NegativePin pin_n annotation(
      Placement(visible = true, transformation(origin = {-100, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Interfaces.PositivePin pin_p annotation(
      Placement(visible = true, transformation(origin = {-100.902, 49.0984}, extent = {{-9.09836, -9.09836}, {9.09836, 9.09836}}, rotation = 0), iconTransformation(origin = {-100, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(fixed.flange, damper.flange_a) annotation(
      Line(points = {{60, -50}, {59.9532, -50}, {59.9532, -35.1288}, {59.9532, -35.1288}}));
    connect(damper.flange_b, inertia.flange_a) annotation(
      Line(points = {{60, -15}, {60, 0}, {64.637, 0}, {64.637, 0}}));
    connect(inertia.flange_b, flange_b) annotation(
      Line(points = {{85, 0}, {97.8923, 0}, {97.8923, -1.40515}, {97.8923, -1.40515}}));
    connect(bearingfriction.flange_b, inertia.flange_a) annotation(
      Line(points = {{50, 0}, {65.1054, 0}, {65.1054, -0.936768}, {65.1054, -0.936768}}));
    connect(emf.flange, bearingfriction.flange_a) annotation(
      Line(points = {{10, 0}, {30.445, 0}, {30.445, -0.468384}, {30.445, -0.468384}}));
    connect(inductor.n, emf.p) annotation(
      Line(points = {{-15, 50}, {0.468384, 50}, {0.468384, 9.83607}, {0.468384, 9.83607}}));
    connect(pin_n, emf.n) annotation(
      Line(points = {{-100, -50}, {0.936768, -50}, {0.936768, -10.7728}, {0.936768, -10.7728}}));
    connect(resistor.n, inductor.p) annotation(
      Line(points = {{-65, 50}, {-34.6604, 50}, {-34.6604, 50.1171}, {-34.6604, 50.1171}}));
    connect(resistor.p, pin_p) annotation(
      Line(points = {{-85, 50}, {-100.234, 50}, {-100.234, 48.7119}, {-100.234, 48.7119}}));
    annotation(
      Documentation(info = "<html>
<head>
<style type=\"text/css\">
h4      { border-radius:8%;background-color: #D8D8D8 ;}
</style>
</head>

<h4>General</h4>
<p>
This is the model of a permanent magnet DC motor, one of the most common electromechanical actuator 
with caractheristics as low inductance and low friction.
It includes dead zone.
</p>

<h4>Implementation</h4>
<strong>DCMotor</strong> is based upon the mathematical model of a 
permanent magnet dc motor.
It is similar to the
<a href=\"modelica://Servomechanisms.Electrical.IdealDCMotor\">
IdealDCMotor
</a> 
class but this model is nonlinear. A dead zone is added by 
using the static friction of 
<a href=\"modelica://Modelica.Mechanics.Rotational.Components.BearingFriction\">
BearingFriction
</a>
component.<br>
Using elements from 
<a href=\"modelica://Modelica\">MSL</a>  
the model was developed to represent the mathematical equations:<br>
<img src=\"modelica://Servomechanisms/Resources/Images/Electrical/dcmotorequation.png\" alt=\"dcmotorequation.png\" >

<h4>Notes</h4>
<ul>
<li>
The behavior of the voltage source is given by a <strong>real input</strong> (for example a real source block could be connected as an input, see 
<a href=\"modelica://Modelica.Blocks.Sources\">Modelica.Blocks.Sources</a>  
).
</li>
<li>This model is linear</li>
<li>All the parameters and variables are in SI units</li>
<li>Has angle and speed sensors as <strong>real outputs</strong> .</li>
</ul>


</html>"),
      Diagram(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})),
      Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2}), graphics = {Text(origin = {-38.7173, -67.4584}, lineColor = {255, 255, 255}, extent = {{-14.4893, 12.3515}, {14.4893, -12.3515}}, textString = "Phi", fontSize = 30), Text(origin = {50.6413, -66.9359}, extent = {{-14.4893, 12.3515}, {14.4893, -12.3515}}, textString = "w", fontSize = 30)}));
  end DCMotor;

  TdMoteurCcChaineTransmissionEleve.DCMotor MCC annotation(
    Placement(visible = true, transformation(origin = {-30, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Electrical.Analog.Sources.ConstantVoltage Umot annotation(
    Placement(visible = true, transformation(origin = {-80, 28}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Basic.Ground ground1 annotation(
    Placement(visible = true, transformation(origin = {-80, -22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Rotational.Components.LossyGear Reducteur(lossTable = [0, 0.8, 0.8, 0, 0]) annotation(
    Placement(visible = true, transformation(origin = {8, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Rotational.Components.IdealRollingWheel Poulie annotation(
    Placement(visible = true, transformation(origin = {46, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Translational.Components.Mass Masse annotation(
    Placement(visible = true, transformation(origin = {76, -6}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Mechanics.Translational.Sources.Force Poids annotation(
    Placement(visible = true, transformation(origin = {52, -32}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.RealExpression realExpression1(y = if Masse.v <> 0 then -Masse.m * 9.81 else 0) annotation(
    Placement(visible = true, transformation(origin = {0, -32}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));

  package SIunits "Library of type and unit definitions based on SI units according to ISO 31-1992"
    extends Modelica.Icons.Package;
    // Space and Time (chapter 1 of ISO 31-1992)
    type Angle = Real(final quantity = "Angle", final unit = "rad", displayUnit = "deg");
    type SolidAngle = Real(final quantity = "SolidAngle", final unit = "sr");
    type Length = Real(final quantity = "Length", final unit = "m");
    type PathLength = Length;
    type Position = Length;
    type Distance = Length(min = 0);
    type Breadth = Length(min = 0);
    type Height = Length(min = 0);
    type Thickness = Length(min = 0);
    type Radius = Length(min = 0);
    type Diameter = Length(min = 0);
    type Area = Real(final quantity = "Area", final unit = "m2");
    type Volume = Real(final quantity = "Volume", final unit = "m3");
    type Time = Real(final quantity = "Time", final unit = "s");
    type Duration = Time;
    type AngularVelocity = Real(final quantity = "AngularVelocity", final unit = "rad/s");
    type AngularAcceleration = Real(final quantity = "AngularAcceleration", final unit = "rad/s2");
    type Velocity = Real(final quantity = "Velocity", final unit = "m/s");
    type Acceleration = Real(final quantity = "Acceleration", final unit = "m/s2");
    // Periodic and related phenomens (chapter 2 of ISO 31-1992)
    type Period = Real(final quantity = "Time", final unit = "s");
    type Frequency = Real(final quantity = "Frequency", final unit = "Hz");
    type AngularFrequency = Real(final quantity = "AngularFrequency", final unit = "rad/s");
    type Wavelength = Real(final quantity = "Wavelength", final unit = "m");
    type Wavelenght = Wavelength;
    // For compatibility reasons only
    type WaveNumber = Real(final quantity = "WaveNumber", final unit = "m-1");
    type CircularWaveNumber = Real(final quantity = "CircularWaveNumber", final unit = "rad/m");
    type AmplitudeLevelDifference = Real(final quantity = "AmplitudeLevelDifference", final unit = "dB");
    type PowerLevelDifference = Real(final quantity = "PowerLevelDifference", final unit = "dB");
    type DampingCoefficient = Real(final quantity = "DampingCoefficient", final unit = "s-1");
    type LogarithmicDecrement = Real(final quantity = "LogarithmicDecrement", final unit = "1/S");
    type AttenuationCoefficient = Real(final quantity = "AttenuationCoefficient", final unit = "m-1");
    type PhaseCoefficient = Real(final quantity = "PhaseCoefficient", final unit = "m-1");
    type PropagationCoefficient = Real(final quantity = "PropagationCoefficient", final unit = "m-1");
    // added to ISO-chapter
    type Damping = DampingCoefficient;
    // Mechanics (chapter 3 of ISO 31-1992)
    type Mass = Real(quantity = "Mass", final unit = "kg", min = 0);
    type Density = Real(final quantity = "Density", final unit = "kg/m3", displayUnit = "g/cm3", min = 0.0);
    type RelativeDensity = Real(final quantity = "RelativeDensity", final unit = "1", min = 0.0);
    type SpecificVolume = Real(final quantity = "SpecificVolume", final unit = "m3/kg", min = 0.0);
    type LinearDensity = Real(final quantity = "LinearDensity", final unit = "kg/m", min = 0);
    type SurfaceDensity = Real(final quantity = "SurfaceDensity", final unit = "kg/m2", min = 0);
    type Momentum = Real(final quantity = "Momentum", final unit = "kg.m/s");
    type Impulse = Real(final quantity = "Impulse", final unit = "N.s");
    type AngularMomentum = Real(final quantity = "AngularMomentum", final unit = "kg.m2/s");
    type AngularImpulse = Real(final quantity = "AngularImpulse", final unit = "N.m.s");
    type MomentOfInertia = Real(final quantity = "MomentOfInertia", final unit = "kg.m2");
    type Inertia = MomentOfInertia;
    type Force = Real(final quantity = "Force", final unit = "N");
    type TranslationalSpringConstant = Real(final quantity = "TranslationalSpringConstant", final unit = "N/m");
    type TranslationalDampingConstant = Real(final quantity = "TranslationalDampingConstant", final unit = "N.s/m");
    type Weight = Force;
    type Torque = Real(final quantity = "Torque", final unit = "N.m");
    type ElectricalTorqueConstant = Real(final quantity = "ElectricalTorqueConstant", final unit = "N.m/A");
    type MomentOfForce = Torque;
    type ImpulseFlowRate = Real(final quantity = "ImpulseFlowRate", final unit = "N");
    type AngularImpulseFlowRate = Real(final quantity = "AngularImpulseFlowRate", final unit = "N.m");
    type RotationalSpringConstant = Real(final quantity = "RotationalSpringConstant", final unit = "N.m/rad");
    type RotationalDampingConstant = Real(final quantity = "RotationalDampingConstant", final unit = "N.m.s/rad");
    type Pressure = Real(final quantity = "Pressure", final unit = "Pa", displayUnit = "bar");
    type AbsolutePressure = Pressure(min = 0.0, nominal = 1e5);
    type PressureDifference = Pressure;
    type BulkModulus = AbsolutePressure;
    type Stress = Real(final unit = "Pa");
    type NormalStress = Stress;
    type ShearStress = Stress;
    type Strain = Real(final quantity = "Strain", final unit = "1");
    type LinearStrain = Strain;
    type ShearStrain = Strain;
    type VolumeStrain = Real(final quantity = "VolumeStrain", final unit = "1");
    type PoissonNumber = Real(final quantity = "PoissonNumber", final unit = "1");
    type ModulusOfElasticity = Stress;
    type ShearModulus = Stress;
    type SecondMomentOfArea = Real(final quantity = "SecondMomentOfArea", final unit = "m4");
    type SecondPolarMomentOfArea = SecondMomentOfArea;
    type SectionModulus = Real(final quantity = "SectionModulus", final unit = "m3");
    type CoefficientOfFriction = Real(final quantity = "CoefficientOfFriction", final unit = "1");
    type DynamicViscosity = Real(final quantity = "DynamicViscosity", final unit = "Pa.s", min = 0);
    type KinematicViscosity = Real(final quantity = "KinematicViscosity", final unit = "m2/s", min = 0);
    type SurfaceTension = Real(final quantity = "SurfaceTension", final unit = "N/m");
    type Work = Real(final quantity = "Work", final unit = "J");
    type Energy = Real(final quantity = "Energy", final unit = "J");
    type EnergyDensity = Real(final quantity = "EnergyDensity", final unit = "J/m3");
    type PotentialEnergy = Energy;
    type KineticEnergy = Energy;
    type Power = Real(final quantity = "Power", final unit = "W");
    type EnergyFlowRate = Power;
    type EnthalpyFlowRate = Real(final quantity = "EnthalpyFlowRate", final unit = "W");
    type Efficiency = Real(final quantity = "Efficiency", final unit = "1", min = 0);
    type MassFlowRate = Real(quantity = "MassFlowRate", final unit = "kg/s");
    type VolumeFlowRate = Real(final quantity = "VolumeFlowRate", final unit = "m3/s");
    // added to ISO-chapter 3
    type MomentumFlux = Real(final quantity = "MomentumFlux", final unit = "N");
    type AngularMomentumFlux = Real(final quantity = "AngularMomentumFlux", final unit = "N.m");
    // Heat (chapter 4 of ISO 31-1992)
    type ThermodynamicTemperature = Real(final quantity = "ThermodynamicTemperature", final unit = "K", min = 0.0, start = 288.15, nominal = 300, displayUnit = "degC") "Absolute temperature (use type TemperatureDifference for relative temperatures)" annotation(
      absoluteValue = true);
    type Temp_K = ThermodynamicTemperature;
    type Temperature = ThermodynamicTemperature;
    type TemperatureDifference = Real(final quantity = "ThermodynamicTemperature", final unit = "K") annotation(
      absoluteValue = false);
    type Temp_C = SIunits.Conversions.NonSIunits.Temperature_degC;
    type TemperatureSlope = Real(final quantity = "TemperatureSlope", final unit = "K/s");
    type LinearTemperatureCoefficient = Real(final quantity = "LinearTemperatureCoefficient", final unit = "1/K");
    type QuadraticTemperatureCoefficient = Real(final quantity = "QuadraticTemperatureCoefficient", final unit = "1/K2");
    type LinearExpansionCoefficient = Real(final quantity = "LinearExpansionCoefficient", final unit = "1/K");
    type CubicExpansionCoefficient = Real(final quantity = "CubicExpansionCoefficient", final unit = "1/K");
    type RelativePressureCoefficient = Real(final quantity = "RelativePressureCoefficient", final unit = "1/K");
    type PressureCoefficient = Real(final quantity = "PressureCoefficient", final unit = "Pa/K");
    type Compressibility = Real(final quantity = "Compressibility", final unit = "1/Pa");
    type IsothermalCompressibility = Compressibility;
    type IsentropicCompressibility = Compressibility;
    type Heat = Real(final quantity = "Energy", final unit = "J");
    type HeatFlowRate = Real(final quantity = "Power", final unit = "W");
    type HeatFlux = Real(final quantity = "HeatFlux", final unit = "W/m2");
    type DensityOfHeatFlowRate = Real(final quantity = "DensityOfHeatFlowRate", final unit = "W/m2");
    type ThermalConductivity = Real(final quantity = "ThermalConductivity", final unit = "W/(m.K)");
    type CoefficientOfHeatTransfer = Real(final quantity = "CoefficientOfHeatTransfer", final unit = "W/(m2.K)");
    type SurfaceCoefficientOfHeatTransfer = CoefficientOfHeatTransfer;
    type ThermalInsulance = Real(final quantity = "ThermalInsulance", final unit = "m2.K/W");
    type ThermalResistance = Real(final quantity = "ThermalResistance", final unit = "K/W");
    type ThermalConductance = Real(final quantity = "ThermalConductance", final unit = "W/K");
    type ThermalDiffusivity = Real(final quantity = "ThermalDiffusivity", final unit = "m2/s");
    type HeatCapacity = Real(final quantity = "HeatCapacity", final unit = "J/K");
    type SpecificHeatCapacity = Real(final quantity = "SpecificHeatCapacity", final unit = "J/(kg.K)");
    type SpecificHeatCapacityAtConstantPressure = SpecificHeatCapacity;
    type SpecificHeatCapacityAtConstantVolume = SpecificHeatCapacity;
    type SpecificHeatCapacityAtSaturation = SpecificHeatCapacity;
    type RatioOfSpecificHeatCapacities = Real(final quantity = "RatioOfSpecificHeatCapacities", final unit = "1");
    type IsentropicExponent = Real(final quantity = "IsentropicExponent", final unit = "1");
    type Entropy = Real(final quantity = "Entropy", final unit = "J/K");
    type EntropyFlowRate = Real(final quantity = "EntropyFlowRate", final unit = "J/(K.s)");
    type SpecificEntropy = Real(final quantity = "SpecificEntropy", final unit = "J/(kg.K)");
    type InternalEnergy = Heat;
    type Enthalpy = Heat;
    type HelmholtzFreeEnergy = Heat;
    type GibbsFreeEnergy = Heat;
    type SpecificEnergy = Real(final quantity = "SpecificEnergy", final unit = "J/kg");
    type SpecificInternalEnergy = SpecificEnergy;
    type SpecificEnthalpy = SpecificEnergy;
    type SpecificHelmholtzFreeEnergy = SpecificEnergy;
    type SpecificGibbsFreeEnergy = SpecificEnergy;
    type MassieuFunction = Real(final quantity = "MassieuFunction", final unit = "J/K");
    type PlanckFunction = Real(final quantity = "PlanckFunction", final unit = "J/K");
    // added to ISO-chapter 4
    type DerDensityByEnthalpy = Real(final unit = "kg.s2/m5");
    type DerDensityByPressure = Real(final unit = "s2/m2");
    type DerDensityByTemperature = Real(final unit = "kg/(m3.K)");
    type DerEnthalpyByPressure = Real(final unit = "J.m.s2/kg2");
    type DerEnergyByDensity = Real(final unit = "J.m3/kg");
    type DerEnergyByPressure = Real(final unit = "J.m.s2/kg");
    type DerPressureByDensity = Real(final unit = "Pa.m3/kg");
    type DerPressureByTemperature = Real(final unit = "Pa/K");
    // Electricity and Magnetism (chapter 5 of ISO 31-1992)
    type ElectricCurrent = Real(final quantity = "ElectricCurrent", final unit = "A");
    type Current = ElectricCurrent;
    type CurrentSlope = Real(final quantity = "CurrentSlope", final unit = "A/s");
    type ElectricCharge = Real(final quantity = "ElectricCharge", final unit = "C");
    type Charge = ElectricCharge;
    type VolumeDensityOfCharge = Real(final quantity = "VolumeDensityOfCharge", final unit = "C/m3", min = 0);
    type SurfaceDensityOfCharge = Real(final quantity = "SurfaceDensityOfCharge", final unit = "C/m2", min = 0);
    type ElectricFieldStrength = Real(final quantity = "ElectricFieldStrength", final unit = "V/m");
    type ElectricPotential = Real(final quantity = "ElectricPotential", final unit = "V");
    type Voltage = ElectricPotential;
    type PotentialDifference = ElectricPotential;
    type ElectromotiveForce = ElectricPotential;
    type VoltageSecond = Real(final quantity = "VoltageSecond", final unit = "V.s") "Voltage second";
    type VoltageSlope = Real(final quantity = "VoltageSlope", final unit = "V/s");
    type ElectricFluxDensity = Real(final quantity = "ElectricFluxDensity", final unit = "C/m2");
    type ElectricFlux = Real(final quantity = "ElectricFlux", final unit = "C");
    type Capacitance = Real(final quantity = "Capacitance", final unit = "F", min = 0);
    type CapacitancePerArea = Real(final quantity = "CapacitancePerArea", final unit = "F/m2") "Capacitance per area";
    type Permittivity = Real(final quantity = "Permittivity", final unit = "F/m", min = 0);
    type PermittivityOfVacuum = Permittivity;
    type RelativePermittivity = Real(final quantity = "RelativePermittivity", final unit = "1");
    type ElectricSusceptibility = Real(final quantity = "ElectricSusceptibility", final unit = "1");
    type ElectricPolarization = Real(final quantity = "ElectricPolarization", final unit = "C/m2");
    type Electrization = Real(final quantity = "Electrization", final unit = "V/m");
    type ElectricDipoleMoment = Real(final quantity = "ElectricDipoleMoment", final unit = "C.m");
    type CurrentDensity = Real(final quantity = "CurrentDensity", final unit = "A/m2");
    type LinearCurrentDensity = Real(final quantity = "LinearCurrentDensity", final unit = "A/m");
    type MagneticFieldStrength = Real(final quantity = "MagneticFieldStrength", final unit = "A/m");
    type MagneticPotential = Real(final quantity = "MagneticPotential", final unit = "A");
    type MagneticPotentialDifference = Real(final quantity = "MagneticPotential", final unit = "A");
    type MagnetomotiveForce = Real(final quantity = "MagnetomotiveForce", final unit = "A");
    type CurrentLinkage = Real(final quantity = "CurrentLinkage", final unit = "A");
    type MagneticFluxDensity = Real(final quantity = "MagneticFluxDensity", final unit = "T");
    type MagneticFlux = Real(final quantity = "MagneticFlux", final unit = "Wb");
    type MagneticVectorPotential = Real(final quantity = "MagneticVectorPotential", final unit = "Wb/m");
    type Inductance = Real(final quantity = "Inductance", final unit = "H");
    type SelfInductance = Inductance(min = 0);
    type MutualInductance = Inductance;
    type CouplingCoefficient = Real(final quantity = "CouplingCoefficient", final unit = "1");
    type LeakageCoefficient = Real(final quantity = "LeakageCoefficient", final unit = "1");
    type Permeability = Real(final quantity = "Permeability", final unit = "H/m");
    type PermeabilityOfVacuum = Permeability;
    type RelativePermeability = Real(final quantity = "RelativePermeability", final unit = "1");
    type MagneticSusceptibility = Real(final quantity = "MagneticSusceptibility", final unit = "1");
    type ElectromagneticMoment = Real(final quantity = "ElectromagneticMoment", final unit = "A.m2");
    type MagneticDipoleMoment = Real(final quantity = "MagneticDipoleMoment", final unit = "Wb.m");
    type Magnetization = Real(final quantity = "Magnetization", final unit = "A/m");
    type MagneticPolarization = Real(final quantity = "MagneticPolarization", final unit = "T");
    type ElectromagneticEnergyDensity = Real(final quantity = "EnergyDensity", final unit = "J/m3");
    type PoyntingVector = Real(final quantity = "PoyntingVector", final unit = "W/m2");
    type Resistance = Real(final quantity = "Resistance", final unit = "Ohm");
    type Resistivity = Real(final quantity = "Resistivity", final unit = "Ohm.m");
    type Conductivity = Real(final quantity = "Conductivity", final unit = "S/m");
    type Reluctance = Real(final quantity = "Reluctance", final unit = "H-1");
    type Permeance = Real(final quantity = "Permeance", final unit = "H");
    type PhaseDifference = Real(final quantity = "Angle", final unit = "rad", displayUnit = "deg");
    type Impedance = Resistance;
    type ModulusOfImpedance = Resistance;
    type Reactance = Resistance;
    type QualityFactor = Real(final quantity = "QualityFactor", final unit = "1");
    type LossAngle = Real(final quantity = "Angle", final unit = "rad", displayUnit = "deg");
    type Conductance = Real(final quantity = "Conductance", final unit = "S");
    type Admittance = Conductance;
    type ModulusOfAdmittance = Conductance;
    type Susceptance = Conductance;
    type InstantaneousPower = Real(final quantity = "Power", final unit = "W");
    type ActivePower = Real(final quantity = "Power", final unit = "W");
    type ApparentPower = Real(final quantity = "Power", final unit = "VA");
    type ReactivePower = Real(final quantity = "Power", final unit = "var");
    type PowerFactor = Real(final quantity = "PowerFactor", final unit = "1");
    // added to ISO-chapter 5
    type Transconductance = Real(final quantity = "Transconductance", final unit = "A/V2");
    type InversePotential = Real(final quantity = "InversePotential", final unit = "1/V");
    type ElectricalForceConstant = Real(final quantity = "ElectricalForceConstant", final unit = "N/A");
    // Light and Related Electromagnetic Radiations (chapter 6 of ISO 31-1992)
    type RadiantEnergy = Real(final quantity = "Energy", final unit = "J");
    type RadiantEnergyDensity = Real(final quantity = "EnergyDensity", final unit = "J/m3");
    type SpectralRadiantEnergyDensity = Real(final quantity = "SpectralRadiantEnergyDensity", final unit = "J/m4");
    type RadiantPower = Real(final quantity = "Power", final unit = "W");
    type RadiantEnergyFluenceRate = Real(final quantity = "RadiantEnergyFluenceRate", final unit = "W/m2");
    type RadiantIntensity = Real(final quantity = "RadiantIntensity", final unit = "W/sr");
    type Radiance = Real(final quantity = "Radiance", final unit = "W/(sr.m2)");
    type RadiantExtiance = Real(final quantity = "RadiantExtiance", final unit = "W/m2");
    type Irradiance = Real(final quantity = "Irradiance", final unit = "W/m2");
    type Emissivity = Real(final quantity = "Emissivity", final unit = "1");
    type SpectralEmissivity = Real(final quantity = "SpectralEmissivity", final unit = "1");
    type DirectionalSpectralEmissivity = Real(final quantity = "DirectionalSpectralEmissivity", final unit = "1");
    type LuminousIntensity = Real(final quantity = "LuminousIntensity", final unit = "cd");
    type LuminousFlux = Real(final quantity = "LuminousFlux", final unit = "lm");
    type QuantityOfLight = Real(final quantity = "QuantityOfLight", final unit = "lm.s");
    type Luminance = Real(final quantity = "Luminance", final unit = "cd/m2");
    type LuminousExitance = Real(final quantity = "LuminousExitance", final unit = "lm/m2");
    type Illuminance = Real(final quantity = "Illuminance", final unit = "lx");
    type LightExposure = Real(final quantity = "LightExposure", final unit = "lx.s");
    type LuminousEfficacy = Real(final quantity = "LuminousEfficacy", final unit = "lm/W");
    type SpectralLuminousEfficacy = Real(final quantity = "SpectralLuminousEfficacy", final unit = "lm/W");
    type LuminousEfficiency = Real(final quantity = "LuminousEfficiency", final unit = "1");
    type SpectralLuminousEfficiency = Real(final quantity = "SpectralLuminousEfficiency", final unit = "1");
    type CIESpectralTristimulusValues = Real(final quantity = "CIESpectralTristimulusValues", final unit = "1");
    type ChromaticityCoordinates = Real(final quantity = "CromaticityCoordinates", final unit = "1");
    type SpectralAbsorptionFactor = Real(final quantity = "SpectralAbsorptionFactor", final unit = "1");
    type SpectralReflectionFactor = Real(final quantity = "SpectralReflectionFactor", final unit = "1");
    type SpectralTransmissionFactor = Real(final quantity = "SpectralTransmissionFactor", final unit = "1");
    type SpectralRadianceFactor = Real(final quantity = "SpectralRadianceFactor", final unit = "1");
    type LinearAttenuationCoefficient = Real(final quantity = "AttenuationCoefficient", final unit = "m-1");
    type LinearAbsorptionCoefficient = Real(final quantity = "LinearAbsorptionCoefficient", final unit = "m-1");
    type MolarAbsorptionCoefficient = Real(final quantity = "MolarAbsorptionCoefficient", final unit = "m2/mol");
    type RefractiveIndex = Real(final quantity = "RefractiveIndex", final unit = "1");
    // Acoustics (chapter 7 of ISO 31-1992)
    type StaticPressure = AbsolutePressure;
    type SoundPressure = StaticPressure;
    type SoundParticleDisplacement = Real(final quantity = "Length", final unit = "m");
    type SoundParticleVelocity = Real(final quantity = "Velocity", final unit = "m/s");
    type SoundParticleAcceleration = Real(final quantity = "Acceleration", final unit = "m/s2");
    type VelocityOfSound = Real(final quantity = "Velocity", final unit = "m/s");
    type SoundEnergyDensity = Real(final quantity = "EnergyDensity", final unit = "J/m3");
    type SoundPower = Real(final quantity = "Power", final unit = "W");
    type SoundIntensity = Real(final quantity = "SoundIntensity", final unit = "W/m2");
    type AcousticImpedance = Real(final quantity = "AcousticImpedance", final unit = "Pa.s/m3");
    type SpecificAcousticImpedance = Real(final quantity = "SpecificAcousticImpedance", final unit = "Pa.s/m");
    type MechanicalImpedance = Real(final quantity = "MechanicalImpedance", final unit = "N.s/m");
    type SoundPressureLevel = Real(final quantity = "SoundPressureLevel", final unit = "dB");
    type SoundPowerLevel = Real(final quantity = "SoundPowerLevel", final unit = "dB");
    type DissipationCoefficient = Real(final quantity = "DissipationCoefficient", final unit = "1");
    type ReflectionCoefficient = Real(final quantity = "ReflectionCoefficient", final unit = "1");
    type TransmissionCoefficient = Real(final quantity = "TransmissionCoefficient", final unit = "1");
    type AcousticAbsorptionCoefficient = Real(final quantity = "AcousticAbsorptionCoefficient", final unit = "1");
    type SoundReductionIndex = Real(final quantity = "SoundReductionIndex", final unit = "dB");
    type EquivalentAbsorptionArea = Real(final quantity = "Area", final unit = "m2");
    type ReverberationTime = Real(final quantity = "Time", final unit = "s");
    type LoudnessLevel = Real(final quantity = "LoudnessLevel", final unit = "phon");
    type Loudness = Real(final quantity = "Loudness", final unit = "sone");
    type LoundnessLevel = Real(final quantity = "LoundnessLevel", final unit = "phon") "Obsolete type, use LoudnessLevel instead!";
    type Loundness = Real(final quantity = "Loundness", final unit = "sone") "Obsolete type, use Loudness instead!";
    // Physical chemistry and molecular physics (chapter 8 of ISO 31-1992)
    type RelativeAtomicMass = Real(final quantity = "RelativeAtomicMass", final unit = "1");
    type RelativeMolecularMass = Real(final quantity = "RelativeMolecularMass", final unit = "1");
    type NumberOfMolecules = Real(final quantity = "NumberOfMolecules", final unit = "1");
    type AmountOfSubstance = Real(final quantity = "AmountOfSubstance", final unit = "mol", min = 0);
    type MolarMass = Real(final quantity = "MolarMass", final unit = "kg/mol", min = 0);
    type MolarVolume = Real(final quantity = "MolarVolume", final unit = "m3/mol", min = 0);
    type MolarDensity = Real(final quantity = "MolarDensity", unit = "mol/m3");
    type MolarEnergy = Real(final quantity = "MolarEnergy", final unit = "J/mol", nominal = 2e4);
    type MolarInternalEnergy = MolarEnergy;
    type MolarHeatCapacity = Real(final quantity = "MolarHeatCapacity", final unit = "J/(mol.K)");
    type MolarEntropy = Real(final quantity = "MolarEntropy", final unit = "J/(mol.K)");
    type MolarEnthalpy = MolarEnergy;
    type MolarFlowRate = Real(final quantity = "MolarFlowRate", final unit = "mol/s");
    type NumberDensityOfMolecules = Real(final quantity = "NumberDensityOfMolecules", final unit = "m-3");
    type MolecularConcentration = Real(final quantity = "MolecularConcentration", final unit = "m-3");
    type MassConcentration = Real(final quantity = "MassConcentration", final unit = "kg/m3");
    type MassFraction = Real(final quantity = "MassFraction", final unit = "1", min = 0, max = 1);
    type Concentration = Real(final quantity = "Concentration", final unit = "mol/m3");
    type VolumeFraction = Real(final quantity = "VolumeFraction", final unit = "1");
    type MoleFraction = Real(final quantity = "MoleFraction", final unit = "1", min = 0, max = 1);
    type ChemicalPotential = Real(final quantity = "ChemicalPotential", final unit = "J/mol");
    type AbsoluteActivity = Real(final quantity = "AbsoluteActivity", final unit = "1");
    type PartialPressure = AbsolutePressure;
    type Fugacity = Real(final quantity = "Fugacity", final unit = "Pa");
    type StandardAbsoluteActivity = Real(final quantity = "StandardAbsoluteActivity", final unit = "1");
    type ActivityCoefficient = Real(final quantity = "ActivityCoefficient", final unit = "1");
    type ActivityOfSolute = Real(final quantity = "ActivityOfSolute", final unit = "1");
    type ActivityCoefficientOfSolute = Real(final quantity = "ActivityCoefficientOfSolute", final unit = "1");
    type StandardAbsoluteActivityOfSolute = Real(final quantity = "StandardAbsoluteActivityOfSolute", final unit = "1");
    type ActivityOfSolvent = Real(final quantity = "ActivityOfSolvent", final unit = "1");
    type OsmoticCoefficientOfSolvent = Real(final quantity = "OsmoticCoefficientOfSolvent", final unit = "1");
    type StandardAbsoluteActivityOfSolvent = Real(final quantity = "StandardAbsoluteActivityOfSolvent", final unit = "1");
    type OsmoticPressure = Real(final quantity = "Pressure", final unit = "Pa", displayUnit = "bar", min = 0);
    type StoichiometricNumber = Real(final quantity = "StoichiometricNumber", final unit = "1");
    type Affinity = Real(final quantity = "Affinity", final unit = "J/mol");
    type MassOfMolecule = Real(final quantity = "Mass", final unit = "kg");
    type ElectricDipoleMomentOfMolecule = Real(final quantity = "ElectricDipoleMomentOfMolecule", final unit = "C.m");
    type ElectricPolarizabilityOfAMolecule = Real(final quantity = "ElectricPolarizabilityOfAMolecule", final unit = "C.m2/V");
    type MicrocanonicalPartitionFunction = Real(final quantity = "MicrocanonicalPartitionFunction", final unit = "1");
    type CanonicalPartitionFunction = Real(final quantity = "CanonicalPartitionFunction", final unit = "1");
    type GrandCanonicalPartitionFunction = Real(final quantity = "GrandCanonicalPartitionFunction", final unit = "1");
    type MolecularPartitionFunction = Real(final quantity = "MolecularPartitionFunction", final unit = "1");
    type StatisticalWeight = Real(final quantity = "StatisticalWeight", final unit = "1");
    type MeanFreePath = Length;
    type DiffusionCoefficient = Real(final quantity = "DiffusionCoefficient", final unit = "m2/s");
    type ThermalDiffusionRatio = Real(final quantity = "ThermalDiffusionRatio", final unit = "1");
    type ThermalDiffusionFactor = Real(final quantity = "ThermalDiffusionFactor", final unit = "1");
    type ThermalDiffusionCoefficient = Real(final quantity = "ThermalDiffusionCoefficient", final unit = "m2/s");
    type ElementaryCharge = Real(final quantity = "ElementaryCharge", final unit = "C");
    type ChargeNumberOfIon = Real(final quantity = "ChargeNumberOfIon", final unit = "1");
    type FaradayConstant = Real(final quantity = "FaradayConstant", final unit = "C/mol");
    type IonicStrength = Real(final quantity = "IonicStrength", final unit = "mol/kg");
    type DegreeOfDissociation = Real(final quantity = "DegreeOfDissociation", final unit = "1");
    type ElectrolyticConductivity = Real(final quantity = "ElectrolyticConductivity", final unit = "S/m");
    type MolarConductivity = Real(final quantity = "MolarConductivity", final unit = "S.m2/mol");
    type TransportNumberOfIonic = Real(final quantity = "TransportNumberOfIonic", final unit = "1");
    // Atomic and Nuclear Physics (chapter 9 of ISO 31-1992)
    type ProtonNumber = Real(final quantity = "ProtonNumber", final unit = "1");
    type NeutronNumber = Real(final quantity = "NeutronNumber", final unit = "1");
    type NucleonNumber = Real(final quantity = "NucleonNumber", final unit = "1");
    type AtomicMassConstant = Real(final quantity = "Mass", final unit = "kg");
    type MassOfElectron = Real(final quantity = "Mass", final unit = "kg");
    type MassOfProton = Real(final quantity = "Mass", final unit = "kg");
    type MassOfNeutron = Real(final quantity = "Mass", final unit = "kg");
    type HartreeEnergy = Real(final quantity = "Energy", final unit = "J");
    type MagneticMomentOfParticle = Real(final quantity = "MagneticMomentOfParticle", final unit = "A.m2");
    type BohrMagneton = MagneticMomentOfParticle;
    type NuclearMagneton = MagneticMomentOfParticle;
    type GyromagneticCoefficient = Real(final quantity = "GyromagneticCoefficient", final unit = "A.m2/(J.s)");
    type GFactorOfAtom = Real(final quantity = "GFactorOfAtom", final unit = "1");
    type GFactorOfNucleus = Real(final quantity = "GFactorOfNucleus", final unit = "1");
    type LarmorAngularFrequency = Real(final quantity = "AngularFrequency", final unit = "s-1");
    type NuclearPrecessionAngularFrequency = Real(final quantity = "AngularFrequency", final unit = "s-1");
    type CyclotronAngularFrequency = Real(final quantity = "AngularFrequency", final unit = "s-1");
    type NuclearQuadrupoleMoment = Real(final quantity = "NuclearQuadrupoleMoment", final unit = "m2");
    type NuclearRadius = Real(final quantity = "Length", final unit = "m");
    type ElectronRadius = Real(final quantity = "Length", final unit = "m");
    type ComptonWavelength = Real(final quantity = "Length", final unit = "m");
    type MassExcess = Real(final quantity = "Mass", final unit = "kg");
    type MassDefect = Real(final quantity = "Mass", final unit = "kg");
    type RelativeMassExcess = Real(final quantity = "RelativeMassExcess", final unit = "1");
    type RelativeMassDefect = Real(final quantity = "RelativeMassDefect", final unit = "1");
    type PackingFraction = Real(final quantity = "PackingFraction", final unit = "1");
    type BindingFraction = Real(final quantity = "BindingFraction", final unit = "1");
    type MeanLife = Real(final quantity = "Time", final unit = "s");
    type LevelWidth = Real(final quantity = "LevelWidth", final unit = "J");
    type Activity = Real(final quantity = "Activity", final unit = "Bq");
    type SpecificActivity = Real(final quantity = "SpecificActivity", final unit = "Bq/kg");
    type DecayConstant = Real(final quantity = "DecayConstant", final unit = "s-1");
    type HalfLife = Real(final quantity = "Time", final unit = "s");
    type AlphaDisintegrationEnergy = Real(final quantity = "Energy", final unit = "J");
    type MaximumBetaParticleEnergy = Real(final quantity = "Energy", final unit = "J");
    type BetaDisintegrationEnergy = Real(final quantity = "Energy", final unit = "J");
    // Nuclear Reactions and Ionizing Radiations (chapter 10 of ISO 31-1992)
    type ReactionEnergy = Real(final quantity = "Energy", final unit = "J");
    type ResonanceEnergy = Real(final quantity = "Energy", final unit = "J");
    type CrossSection = Real(final quantity = "Area", final unit = "m2");
    type TotalCrossSection = Real(final quantity = "Area", final unit = "m2");
    type AngularCrossSection = Real(final quantity = "AngularCrossSection", final unit = "m2/sr");
    type SpectralCrossSection = Real(final quantity = "SpectralCrossSection", final unit = "m2/J");
    type SpectralAngularCrossSection = Real(final quantity = "SpectralAngularCrossSection", final unit = "m2/(sr.J)");
    type MacroscopicCrossSection = Real(final quantity = "MacroscopicCrossSection", final unit = "m-1");
    type TotalMacroscopicCrossSection = Real(final quantity = "TotalMacroscopicCrossSection", final unit = "m-1");
    type ParticleFluence = Real(final quantity = "ParticleFluence", final unit = "m-2");
    type ParticleFluenceRate = Real(final quantity = "ParticleFluenceRate", final unit = "s-1.m2");
    type EnergyFluence = Real(final quantity = "EnergyFluence", final unit = "J/m2");
    type EnergyFluenceRate = Real(final quantity = "EnergyFluenceRate", final unit = "W/m2");
    type CurrentDensityOfParticles = Real(final quantity = "CurrentDensityOfParticles", final unit = "m-2.s-1");
    type MassAttenuationCoefficient = Real(final quantity = "MassAttenuationCoefficient", final unit = "m2/kg");
    type MolarAttenuationCoefficient = Real(final quantity = "MolarAttenuationCoefficient", final unit = "m2/mol");
    type AtomicAttenuationCoefficient = Real(final quantity = "AtomicAttenuationCoefficient", final unit = "m2");
    type HalfThickness = Real(final quantity = "Length", final unit = "m");
    type TotalLinearStoppingPower = Real(final quantity = "TotalLinearStoppingPower", final unit = "J/m");
    type TotalAtomicStoppingPower = Real(final quantity = "TotalAtomicStoppingPower", final unit = "J.m2");
    type TotalMassStoppingPower = Real(final quantity = "TotalMassStoppingPower", final unit = "J.m2/kg");
    type MeanLinearRange = Real(final quantity = "Length", final unit = "m");
    type MeanMassRange = Real(final quantity = "MeanMassRange", final unit = "kg/m2");
    type LinearIonization = Real(final quantity = "LinearIonization", final unit = "m-1");
    type TotalIonization = Real(final quantity = "TotalIonization", final unit = "1");
    type Mobility = Real(final quantity = "Mobility", final unit = "m2/(V.s)");
    type IonNumberDensity = Real(final quantity = "IonNumberDensity", final unit = "m-3");
    type RecombinationCoefficient = Real(final quantity = "RecombinationCoefficient", final unit = "m3/s");
    type NeutronNumberDensity = Real(final quantity = "NeutronNumberDensity", final unit = "m-3");
    type NeutronSpeed = Real(final quantity = "Velocity", final unit = "m/s");
    type NeutronFluenceRate = Real(final quantity = "NeutronFluenceRate", final unit = "s-1.m-2");
    type TotalNeutronSourceDensity = Real(final quantity = "TotalNeutronSourceDesity", final unit = "s-1.m-3");
    type SlowingDownDensity = Real(final quantity = "SlowingDownDensity", final unit = "s-1.m-3");
    type ResonanceEscapeProbability = Real(final quantity = "ResonanceEscapeProbability", final unit = "1");
    type Lethargy = Real(final quantity = "Lethargy", final unit = "1");
    type SlowingDownArea = Real(final quantity = "Area", final unit = "m2");
    type DiffusionArea = Real(final quantity = "Area", final unit = "m2");
    type MigrationArea = Real(final quantity = "Area", final unit = "m2");
    type SlowingDownLength = Real(final quantity = "SLength", final unit = "m");
    type DiffusionLength = Length;
    type MigrationLength = Length;
    type NeutronYieldPerFission = Real(final quantity = "NeutronYieldPerFission", final unit = "1");
    type NeutronYieldPerAbsorption = Real(final quantity = "NeutronYieldPerAbsorption", final unit = "1");
    type FastFissionFactor = Real(final quantity = "FastFissionFactor", final unit = "1");
    type ThermalUtilizationFactor = Real(final quantity = "ThermalUtilizationFactor", final unit = "1");
    type NonLeakageProbability = Real(final quantity = "NonLeakageProbability", final unit = "1");
    type Reactivity = Real(final quantity = "Reactivity", final unit = "1");
    type ReactorTimeConstant = Real(final quantity = "Time", final unit = "s");
    type EnergyImparted = Real(final quantity = "Energy", final unit = "J");
    type MeanEnergyImparted = Real(final quantity = "Energy", final unit = "J");
    type SpecificEnergyImparted = Real(final quantity = "SpecificEnergy", final unit = "Gy");
    type AbsorbedDose = Real(final quantity = "AbsorbedDose", final unit = "Gy");
    type DoseEquivalent = Real(final quantity = "DoseEquivalent", final unit = "Sv");
    type AbsorbedDoseRate = Real(final quantity = "AbsorbedDoseRate", final unit = "Gy/s");
    type LinearEnergyTransfer = Real(final quantity = "LinearEnergyTransfer", final unit = "J/m");
    type Kerma = Real(final quantity = "Kerma", final unit = "Gy");
    type KermaRate = Real(final quantity = "KermaRate", final unit = "Gy/s");
    type MassEnergyTransferCoefficient = Real(final quantity = "MassEnergyTransferCoefficient", final unit = "m2/kg");
    type Exposure = Real(final quantity = "Exposure", final unit = "C/kg");
    type ExposureRate = Real(final quantity = "ExposureRate", final unit = "C/(kg.s)");
    // chapter 11 is not defined in ISO 31-1992
    // Characteristic Numbers (chapter 12 of ISO 31-1992)
    type ReynoldsNumber = Real(final quantity = "ReynoldsNumber", final unit = "1");
    type EulerNumber = Real(final quantity = "EulerNumber", final unit = "1");
    type FroudeNumber = Real(final quantity = "FroudeNumber", final unit = "1");
    type GrashofNumber = Real(final quantity = "GrashofNumber", final unit = "1");
    type WeberNumber = Real(final quantity = "WeberNumber", final unit = "1");
    type MachNumber = Real(final quantity = "MachNumber", final unit = "1");
    type KnudsenNumber = Real(final quantity = "KnudsenNumber", final unit = "1");
    type StrouhalNumber = Real(final quantity = "StrouhalNumber", final unit = "1");
    type FourierNumber = Real(final quantity = "FourierNumber", final unit = "1");
    type PecletNumber = Real(final quantity = "PecletNumber", final unit = "1");
    type RayleighNumber = Real(final quantity = "RayleighNumber", final unit = "1");
    type NusseltNumber = Real(final quantity = "NusseltNumber", final unit = "1");
    type BiotNumber = NusseltNumber;
    // The Biot number (Bi) is used when
    // the Nusselt number is reserved
    // for convective transport of heat.
    type StantonNumber = Real(final quantity = "StantonNumber", final unit = "1");
    type FourierNumberOfMassTransfer = Real(final quantity = "FourierNumberOfMassTransfer", final unit = "1");
    type PecletNumberOfMassTransfer = Real(final quantity = "PecletNumberOfMassTransfer", final unit = "1");
    type GrashofNumberOfMassTransfer = Real(final quantity = "GrashofNumberOfMassTransfer", final unit = "1");
    type NusseltNumberOfMassTransfer = Real(final quantity = "NusseltNumberOfMassTransfer", final unit = "1");
    type StantonNumberOfMassTransfer = Real(final quantity = "StantonNumberOfMassTransfer", final unit = "1");
    type PrandtlNumber = Real(final quantity = "PrandtlNumber", final unit = "1");
    type SchmidtNumber = Real(final quantity = "SchmidtNumber", final unit = "1");
    type LewisNumber = Real(final quantity = "LewisNumber", final unit = "1");
    type MagneticReynoldsNumber = Real(final quantity = "MagneticReynoldsNumber", final unit = "1");
    type AlfvenNumber = Real(final quantity = "AlfvenNumber", final unit = "1");
    type HartmannNumber = Real(final quantity = "HartmannNumber", final unit = "1");
    type CowlingNumber = Real(final quantity = "CowlingNumber", final unit = "1");
    // Solid State Physics (chapter 13 of ISO 31-1992)
    type BraggAngle = Angle;
    type OrderOfReflexion = Real(final quantity = "OrderOfReflexion", final unit = "1");
    type ShortRangeOrderParameter = Real(final quantity = "RangeOrderParameter", final unit = "1");
    type LongRangeOrderParameter = Real(final quantity = "RangeOrderParameter", final unit = "1");
    type DebyeWallerFactor = Real(final quantity = "DebyeWallerFactor", final unit = "1");
    type CircularWavenumber = Real(final quantity = "CircularWavenumber", final unit = "m-1");
    type FermiCircularWavenumber = Real(final quantity = "FermiCircularWavenumber", final unit = "m-1");
    type DebyeCircularWavenumber = Real(final quantity = "DebyeCircularWavenumber", final unit = "m-1");
    type DebyeCircularFrequency = Real(final quantity = "AngularFrequency", final unit = "s-1");
    type DebyeTemperature = ThermodynamicTemperature;
    type SpectralConcentration = Real(final quantity = "SpectralConcentration", final unit = "s/m3");
    type GrueneisenParameter = Real(final quantity = "GrueneisenParameter", final unit = "1");
    type MadelungConstant = Real(final quantity = "MadelungConstant", final unit = "1");
    type DensityOfStates = Real(final quantity = "DensityOfStates", final unit = "J-1/m-3");
    type ResidualResistivity = Real(final quantity = "ResidualResistivity", final unit = "Ohm.m");
    type LorenzCoefficient = Real(final quantity = "LorenzCoefficient", final unit = "V2/K2");
    type HallCoefficient = Real(final quantity = "HallCoefficient", final unit = "m3/C");
    type ThermoelectromotiveForce = Real(final quantity = "ThermoelectromotiveForce", final unit = "V");
    type SeebeckCoefficient = Real(final quantity = "SeebeckCoefficient", final unit = "V/K");
    type PeltierCoefficient = Real(final quantity = "PeltierCoefficient", final unit = "V");
    type ThomsonCoefficient = Real(final quantity = "ThomsonCoefficient", final unit = "V/K");
    type RichardsonConstant = Real(final quantity = "RichardsonConstant", final unit = "A/(m2.K2)");
    type FermiEnergy = Real(final quantity = "Energy", final unit = "eV");
    type GapEnergy = Real(final quantity = "Energy", final unit = "eV");
    type DonorIonizationEnergy = Real(final quantity = "Energy", final unit = "eV");
    type AcceptorIonizationEnergy = Real(final quantity = "Energy", final unit = "eV");
    type ActivationEnergy = Real(final quantity = "Energy", final unit = "eV");
    type FermiTemperature = ThermodynamicTemperature;
    type ElectronNumberDensity = Real(final quantity = "ElectronNumberDensity", final unit = "m-3");
    type HoleNumberDensity = Real(final quantity = "HoleNumberDensity", final unit = "m-3");
    type IntrinsicNumberDensity = Real(final quantity = "IntrinsicNumberDensity", final unit = "m-3");
    type DonorNumberDensity = Real(final quantity = "DonorNumberDensity", final unit = "m-3");
    type AcceptorNumberDensity = Real(final quantity = "AcceptorNumberDensity", final unit = "m-3");
    type EffectiveMass = Mass;
    type MobilityRatio = Real(final quantity = "MobilityRatio", final unit = "1");
    type RelaxationTime = Time;
    type CarrierLifeTime = Time;
    type ExchangeIntegral = Real(final quantity = "Energy", final unit = "eV");
    type CurieTemperature = ThermodynamicTemperature;
    type NeelTemperature = ThermodynamicTemperature;
    type LondonPenetrationDepth = Length;
    type CoherenceLength = Length;
    type LandauGinzburgParameter = Real(final quantity = "LandauGinzburgParameter", final unit = "1");
    type FluxiodQuantum = Real(final quantity = "FluxiodQuantum", final unit = "Wb");
    type TimeAging = Real(final quantity = "1/Modelica.SIunits.Time", final unit = "1/s");
    type ChargeAging = Real(final quantity = "1/Modelica.SIunits.ElectricCharge", final unit = "1/(A.s)");
    // Other types not defined in ISO 31-1992
    type PerUnit = Real(unit = "1");
    type DimensionlessRatio = Real(unit = "1");
    // Complex types for electrical systems (not defined in ISO 31-1992)
    annotation(
      Icon(coordinateSystem(preserveAspectRatio = false, extent = {{-100, -100}, {100, 100}}), graphics = {Line(points = {{-66, 78}, {-66, -40}}, color = {64, 64, 64}), Ellipse(extent = {{12, 36}, {68, -38}}, lineColor = {64, 64, 64}, fillColor = {175, 175, 175}, fillPattern = FillPattern.Solid), Rectangle(extent = {{-74, 78}, {-66, -40}}, lineColor = {64, 64, 64}, fillColor = {175, 175, 175}, fillPattern = FillPattern.Solid), Polygon(points = {{-66, -4}, {-66, 6}, {-16, 56}, {-16, 46}, {-66, -4}}, lineColor = {64, 64, 64}, fillColor = {175, 175, 175}, fillPattern = FillPattern.Solid), Polygon(points = {{-46, 16}, {-40, 22}, {-2, -40}, {-10, -40}, {-46, 16}}, lineColor = {64, 64, 64}, fillColor = {175, 175, 175}, fillPattern = FillPattern.Solid), Ellipse(extent = {{22, 26}, {58, -28}}, lineColor = {64, 64, 64}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid), Polygon(points = {{68, 2}, {68, -46}, {64, -60}, {58, -68}, {48, -72}, {18, -72}, {18, -64}, {46, -64}, {54, -60}, {58, -54}, {60, -46}, {60, -26}, {64, -20}, {68, -6}, {68, 2}}, lineColor = {64, 64, 64}, smooth = Smooth.Bezier, fillColor = {175, 175, 175}, fillPattern = FillPattern.Solid)}),
      Documentation(info = "<html>
<p>This package provides predefined types, such as <i>Mass</i>,
<i>Angle</i>, <i>Time</i>, based on the international standard
on units, e.g.,
</p>

<pre>   <b>type</b> Angle = Real(<b>final</b> quantity = \"Angle\",
                     <b>final</b> unit     = \"rad\",
                     displayUnit    = \"deg\");
</pre>

<p>
Some of the types are derived SI units that are utilized in package Modelica
(such as ComplexCurrent, which is a complex number where both the real and imaginary
part have the SI unit Ampere).
</p>

<p>
Furthermore, conversion functions from non SI-units to SI-units and vice versa
are provided in subpackage
<a href=\"modelica://Modelica.SIunits.Conversions\">Conversions</a>.
</p>

<p>
For an introduction how units are used in the Modelica standard library
with package SIunits, have a look at:
<a href=\"modelica://Modelica.SIunits.UsersGuide.HowToUseSIunits\">How to use SIunits</a>.
</p>

<p>
Copyright &copy; 1998-2016, Modelica Association and DLR.
</p>
<p>
<i>This Modelica package is <u>free</u> software and the use is completely at <u>your own risk</u>; it can be redistributed and/or modified under the terms of the Modelica License 2. For license conditions (including the disclaimer of warranty) see <a href=\"modelica://Modelica.UsersGuide.ModelicaLicense2\">Modelica.UsersGuide.ModelicaLicense2</a> or visit <a href=\"https://www.modelica.org/licenses/ModelicaLicense2\"> https://www.modelica.org/licenses/ModelicaLicense2</a>.</i>
</p>
</html>", revisions = "<html>
<ul>
<li><i>May 25, 2011</i> by Stefan Wischhusen:<br/>Added molar units for energy and enthalpy.</li>
<li><i>Jan. 27, 2010</i> by Christian Kral:<br/>Added complex units.</li>
<li><i>Dec. 14, 2005</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Add User&#39;;s Guide and removed &quot;min&quot; values for Resistance and Conductance.</li>
<li><i>October 21, 2002</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and Christian Schweiger:<br/>Added new package <b>Conversions</b>. Corrected typo <i>Wavelenght</i>.</li>
<li><i>June 6, 2000</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Introduced the following new types<br/>type Temperature = ThermodynamicTemperature;<br/>types DerDensityByEnthalpy, DerDensityByPressure, DerDensityByTemperature, DerEnthalpyByPressure, DerEnergyByDensity, DerEnergyByPressure<br/>Attribute &quot;final&quot; removed from min and max values in order that these values can still be changed to narrow the allowed range of values.<br/>Quantity=&quot;Stress&quot; removed from type &quot;Stress&quot;, in order that a type &quot;Stress&quot; can be connected to a type &quot;Pressure&quot;.</li>
<li><i>Oct. 27, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>New types due to electrical library: Transconductance, InversePotential, Damping.</li>
<li><i>Sept. 18, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Renamed from SIunit to SIunits. Subpackages expanded, i.e., the SIunits package, does no longer contain subpackages.</li>
<li><i>Aug 12, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Type &quot;Pressure&quot; renamed to &quot;AbsolutePressure&quot; and introduced a new type &quot;Pressure&quot; which does not contain a minimum of zero in order to allow convenient handling of relative pressure. Redefined BulkModulus as an alias to AbsolutePressure instead of Stress, since needed in hydraulics.</li>
<li><i>June 29, 1999</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a>:<br/>Bug-fix: Double definition of &quot;Compressibility&quot; removed and appropriate &quot;extends Heat&quot; clause introduced in package SolidStatePhysics to incorporate ThermodynamicTemperature.</li>
<li><i>April 8, 1998</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and Astrid Jaschinski:<br/>Complete ISO 31 chapters realized.</li>
<li><i>Nov. 15, 1997</i> by <a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a> and Hubertus Tummescheit:<br/>Some chapters realized.</li>
</ul>
</html>"));
  end SIunits;
equation
  connect(realExpression1.y, Poids.f) annotation(
    Line(points = {{11, -32}, {25, -32}, {25, -32}, {39, -32}, {39, -32}, {38, -32}, {38, -32}, {39, -32}}, color = {0, 0, 127}));
  connect(Masse.flange_b, Poids.flange) annotation(
    Line(points = {{76, -16}, {76, -24}, {76, -24}, {76, -32}, {70, -32}, {70, -32}, {62, -32}}, color = {0, 127, 0}));
  connect(Poulie.flangeT, Masse.flange_a) annotation(
    Line(points = {{56, 30}, {67, 30}, {67, 30}, {76, 30}, {76, 4}, {76, 4}, {76, 4}, {76, 4}}, color = {0, 127, 0}));
  connect(Reducteur.flange_b, Poulie.flangeR) annotation(
    Line(points = {{18, 30}, {27, 30}, {27, 30}, {36, 30}, {36, 30}, {37, 30}, {37, 30}, {36, 30}}));
  connect(MCC.flange_b, Reducteur.flange_a) annotation(
    Line(points = {{-20, 30}, {-11, 30}, {-11, 30}, {-2, 30}, {-2, 30}, {-2, 30}}));
  connect(ground1.p, Umot.n) annotation(
    Line(points = {{-80, -12}, {-80, 18}}, color = {0, 0, 255}));
  connect(Umot.p, MCC.pin_p) annotation(
    Line(points = {{-80, 38}, {-80, 38}, {-80, 52}, {-40, 52}, {-40, 36}, {-40, 36}}, color = {0, 0, 255}));
  connect(Umot.n, MCC.pin_n) annotation(
    Line(points = {{-80, 18}, {-80, 18}, {-80, 8}, {-40, 8}, {-40, 24}, {-40, 24}}, color = {0, 0, 255}));
  annotation(
    Diagram,
    Icon,
    version = "",
    uses(Modelica(version = "3.2.2")),
    __OpenModelica_commandLineOptions = "");
end TdMoteurCcChaineTransmissionEleve;
